@@ -29,20 +29,17 @@ def pypi_index(ctx, req):
     if packageIndex is None:
         return ctx.responseText('404 Not Found', 'Not Found')
 
-    # Build the link URLs
-    linkUrls = ['../../pypi_download/{package}/{version}/{filename}{hash}' \
-                .format(package = urllib.quote(pe.name),
-                        version = urllib.quote(pe.version),
-                        filename = urllib.quote(pe.filename),
-                        hash = (('#' + urllib.quote(pe.hash_name) + '=' + urllib.quote(pe.hash))
-                                if pe.hash is not None else ''))
-                for pe in packageIndex]
-
     # Build the link HTML
-    linkHtmls = ['<a href={linkUrlHref} rel="internal">{linkUrlText}</a><br/>' \
-                 .format(linkUrlHref = saxutils.quoteattr(linkUrl),
-                         linkUrlText = cgi.escape(linkUrl))
-                 for linkUrl in linkUrls]
+    linkHtmls = [
+        '<a href={linkUrlHref} rel="internal">{filenameText}</a><br/>'.format(
+            linkUrlHref = saxutils.quoteattr('../../pypi_download/{package}/{version}/{filename}{hash}'.format(
+                package = urllib.quote(pe.name),
+                version = urllib.quote(pe.version),
+                filename = urllib.quote(pe.filename),
+                hash = (('#' + urllib.quote(pe.hash_name) + '=' + urllib.quote(pe.hash))
+                        if pe.hash is not None else ''))),
+            filenameText = cgi.escape(pe.filename))
+        for pe in packageIndex]
 
     # Build the index response
     response = '''\
@@ -104,16 +101,14 @@ def pypi_upload(environ, start_response):
         return ctx.responseText('400 Bad Request', '')
     parts = cgi.parse_multipart(ctx.environ['wsgi.input'], pdict)
 
-    def getPart(key, expectedType = str, minLen = 1, strip = True):
+    def getPart(key, strip = True):
         values = parts.get(key)
         if values is None or not isinstance(values, list) or len(values) != 1:
             return None
         value = values[0]
-        if not isinstance(value, expectedType):
-            return None
         if strip:
             value = value.strip()
-        if minLen is not None and len(value) < minLen:
+        if len(value) <= 0:
             return None
         return value
 
@@ -125,17 +120,17 @@ def pypi_upload(environ, start_response):
         filetype = getPart('filetype')
         package = getPart('name')
         version = getPart('version')
-        content = getPart('content', expectedType = bytes, strip = False)
+        content = getPart('content', strip = False)
         if filetype not in _uploadFiletypeToExt or package is None or version is None or content is None:
-            return ctx.responseText('400 Bad Request', 'Bad Request')
+            return ctx.responseText('400 Bad Request', '')
 
         # Add the package to the index
         filename = package + '-' + version + _uploadFiletypeToExt[filetype]
         result = ctx.index.addPackage(ctx, package, version, filename, content)
         return ctx.responseText('200 OK' if result else '400 File Exists', '')
 
-    else: # Unknown action
-        return ctx.responseText('400 Bad Request', 'Bad Request')
+    # Unknown action
+    return ctx.responseText('400 Bad Request', '')
 
 
 #
